==> inferno-bootstrap-5.1.0.tgz: package/lib/Table.js <==
function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import { createElement } from 'inferno-create-element';
import classNames from 'classnames';
import { mapToCssModules } from './utils';

var defaultProps = {
  tag: 'table',
  responsiveTag: 'div'
};

var Table = function Table(props) {
  var children = props.children,
      className = props.className,
      cssModule = props.cssModule,
      size = props.size,
      bordered = props.bordered,
      striped = props.striped,
      inverse = props.inverse,
      dark = props.dark,
      hover = props.hover,
      responsive = props.responsive,
      Tag = props.tag,
      ResponsiveTag = props.responsiveTag,
      attributes = _objectWithoutProperties(props, ['children', 'className', 'cssModule', 'size', 'bordered', 'striped', 'inverse', 'dark', 'hover', 'responsive', 'tag', 'responsiveTag']);

  var classes = mapToCssModules(classNames(className, 'table', size ? 'table-' + size : false, bordered ? 'table-bordered' : false, striped ? 'table-striped' : false, dark || inverse ? 'table-dark' : false, hover ? 'table-hover' : false), cssModule);

  Object.assign(attributes, { className: classes });

  var table = createElement(Tag, attributes, children);

  if (responsive) {
    var responsiveClassName = responsive === true ? 'table-responsive' : 'table-responsive-' + responsive;

    return createElement(ResponsiveTag, { className: responsiveClassName }, table);
  }

  return table;
};

Table.defaultProps = defaultProps;

export default Table;

==> inferno-bootstrap-6.0.0.tgz: package/lib/Table.js <==
import _objectWithoutProperties from "/Users/jhsware/node/lerna-inferno-modules/packages/inferno-bootstrap/node_modules/@babel/runtime/helpers/esm/objectWithoutProperties";
import { createElement } from 'inferno-create-element';
import classNames from 'classnames';
import { mapToCssModules } from './utils';
var defaultProps = {
  tag: 'table',
  responsiveTag: 'div'
};

var Table = function Table(props) {
  var children = props.children,
      className = props.className,
      cssModule = props.cssModule,
      size = props.size,
      bordered = props.bordered,
      striped = props.striped,
      inverse = props.inverse,
      dark = props.dark,
      hover = props.hover,
      responsive = props.responsive,
      Tag = props.tag,
      ResponsiveTag = props.responsiveTag,
      attributes = _objectWithoutProperties(props, ["children", "className", "cssModule", "size", "bordered", "striped", "inverse", "dark", "hover", "responsive", "tag", "responsiveTag"]);

  var classes = mapToCssModules(classNames(className, 'table', size ? 'table-' + size : false, bordered ? 'table-bordered' : false, striped ? 'table-striped' : false, dark || inverse ? 'table-dark' : false, hover ? 'table-hover' : false), cssModule);
  Object.assign(attributes, {
    className: classes
  });
  var table = createElement(Tag, attributes, children);

  if (responsive) {
    var responsiveClassName = responsive === true ? 'table-responsive' : "table-responsive-".concat(responsive);
    return createElement(ResponsiveTag, {
      className: responsiveClassName
    }, table);
  }

  return table;
};

Table.defaultProps = defaultProps;
export default Table;
